diff --git a/hspread.cabal b/hspread.cabal
--- a/hspread.cabal
+++ b/hspread.cabal
@@ -1,5 +1,5 @@
 name:		hspread
-version: 	0.3.2
+version: 	0.3.3
 license:	BSD3
 license-file:	LICENSE
 author:		Andrea Vezzosi

diff --git a/Spread/Client/Connection.hs b/Spread/Client/Connection.hs
--- a/Spread/Client/Connection.hs
+++ b/Spread/Client/Connection.hs
@@ -31,7 +31,7 @@
 data Connection = C {privateGroup :: !PrivateGroup -- ^ private name of this connection, useful for p2p messages.
                     , chan :: !(Chan W Message), getHandle :: !Handle, thread :: !ThreadId, sync :: !(MVar ()) }
 -- | Configuration passed to 'connect' 
-data Conf = Conf { address :: !(Maybe HostName)    -- ^ Server address, using localhost if 'Nothing'.
+data Conf = Conf { address :: !(Maybe HostName)    -- ^ Server address, using 127.0.0.1 if 'Nothing'.
                  , port :: !(Maybe PortNumber)     -- ^ Server port, uses the default spread port if 'Nothing'.
                  , desiredName :: !PrivateName     -- ^ It will become part of the 'PrivateGroup' of the 'Connection'
                  , priority :: !Bool               -- ^ Is this a priority connection?
@@ -57,7 +57,7 @@
 -- A spread server will refuse the connection if another with the same PrivateName is still active.
 connect :: Conf -> IO (Chan R Message,Connection)
 connect c = 
-  let addr = fromMaybe "localhost" . address $ c
+  let addr = fromMaybe "127.0.0.1" . address $ c
       port' = fromMaybe dEFAULT_SPREAD_PORT . port $ c
       (authnames,authmethods) = unzip $ let l = authMethods c in if null l then [nullAuthMethod] else l
   in bracketOnError (withSocketsDo $ connectTo addr (PortNumber port')) hClose $ \h -> do